from browser.html import _mockbrython


class ObjectStorage(dict):
    def __init__(self, s):
        pass

    def __getitem__(self, x):
        return _mockbrython

    def __setitem__(self, attr, value):
        pass





"""
Mock brython functions for local testing and debugging.

WHen installed with pip running a script containing brython calls will catch syntax errors 
without hitting unresolved brython calls

$ python devel_script.py

The script can also be debugged using idle, our your IDE of choice
"""

"""
class _mockbrython1(dict):
    items = []

    def __le__(self, other):
        self.items.append(other)

    def __missing__(self, attr):
        return _mockbrython()

    def __getattr__(self, attr):
        return _mockbrython()

    def __setattr__(self, attr, value):
        pass

    def __hash__(self):
        return 0

"""

class _mockbrython(dict):
    def __init__(self, *args, **kwargs):
        self.style = self #_mockbrython1()
        self.args = args
        self.kwargs = kwargs
        for k, v in kwargs.items():
            setattr(self, k, v)
        pass

    def __call__(self, *args, **kwargs):
        return self

    def __le__(self, other):
        pass

    def __add__(self, other):
        """ Brython overloads the add operater to concatenate 2 brython objects
            We mock this by returning a _mockbrython, 
            except where the other operand is an int when we return a zero
        """

        if type(other) == _mockbrython:
            return self
        else:
            return 0

    def __radd__(self, other):
        """ and make symmetric """
        if type(other) == _mockbrython:
            return self
        else:
            return 0

    def __sub__(self, other):
        return 0

    def __int__(self):
        return 0

    def __mul__(self, other):
        return 0

    def __truediv__(self, other):
        return 0

    def __getattr__(self, attr):
        return self

    def __getitem__(self, attr):
        return self

    def __eq__(self, other):
        return True

    def __hash__(self):
        return 0


document = _mockbrython()


def alert(*args, **kwargs):
    pass


""" This is not what @bind does in real life. 
    We just supply a hook that can be called to exercise the event handler
"""


def bind(target, evt):
    def decorator(func):
        def wrapper(evt):
            func(evt)
        return wrapper
    return decorator


self = _mockbrython()








from browser.html import _mockbrython


async def ajax(method, url, format="text", headers=None, data=None, cache=False):
    return _mockbrython()


async def get(url, format="text", headers=None, data=None, cache=False):
    return _mockbrython()


async def post(url, format="text", headers=None, data=None):
    return _mockbrython()

_event_return = _mockbrython()
""" If you want to force """


async def event(element, name):
    return _event_return

# evt = await aio.event(element, "click") suspends execution of an asynchronous function until the user clicks on the specified element. The return value is an instance of the DOMEvent class (cf. section events)


def sleep(seconds):
    pass


import asyncio

## the following needs python >= 3.7 Dont use it if running older version
def run(coroutine):
    asyncio.run(coroutine)
    pass




from browser import _mockbrython


def InfoDialog(title, message, *, top=None, left=None, default_css=True, remove_after=None, ok=False):
    pass


def EntryDialog(title, message=None, *, top=None, left=None, default_css=True, ok=True):
    return _mockbrython()


def Dialog(title, *, top=None, left=None, default_css=True, ok_cancel=False):
    return _mockbrython()





from browser import _mockbrython

""" SVG emulation """

a = _mockbrython
altGlyph = _mockbrython
altGlyphDef = _mockbrython
altGlyphItem = _mockbrython
animate = _mockbrython
animateColor = _mockbrython
animateMotion = _mockbrython
animateTransform = _mockbrython
circle = _mockbrython
clipPath = _mockbrython
color_profile = _mockbrython
cursor = _mockbrython
defs = _mockbrython
desc = _mockbrython
ellipse = _mockbrython
feBlend = _mockbrython
g = _mockbrython
image = _mockbrython
line = _mockbrython
linearGradient = _mockbrython
marker = _mockbrython
mask = _mockbrython
path = _mockbrython
pattern = _mockbrython
polygon = _mockbrython
polyline = _mockbrython
radialGradient = _mockbrython
rect = _mockbrython
stop = _mockbrython
svg = _mockbrython
text = _mockbrython
tref = _mockbrython
tspan = _mockbrython
use = _mockbrython





from browser.html import _mockbrython
Ajax = _mockbrython


async def ajax(method, url, format="text", headers=None, data=None, cache=False):
    return _mockbrython()


def get(url, blocking=False, headers={}, mode="text", encoding="utf-8", timeout=None, cache=False, data="", **callbacks):
    return _mockbrython()


def post(url, blocking=False, headers={"Content-Type": "application/x-www-form-urlencoded"}, timeout=None, data="", **callbacks):
    return _mockbrython()


def file_upload(url, file, method="POST", field_name="filetosave", **callbacks):
    return _mockbrython()




from browser import _mockbrython

supported = True

class _Websocket():
    def bind(self, evt, function):
        pass

    def send(self, data):
        pass

    def close(self):
        pass


def WebSocket(host):
    return _Websocket()






from browser import _mockbrython


""" HTML4 tags """

A = _mockbrython
ABBR = _mockbrython
ACRONYM = _mockbrython
ADDRESS = _mockbrython
APPLET = _mockbrython
AREA = _mockbrython
B = _mockbrython
BASE = _mockbrython
BASEFONT = _mockbrython
BDO = _mockbrython
BIG = _mockbrython
BLOCKQUOTE = _mockbrython
BODY = _mockbrython
BR = _mockbrython
BUTTON = _mockbrython
CAPTION = _mockbrython
CENTER = _mockbrython
CITE = _mockbrython
CODE = _mockbrython
COL = _mockbrython
COLGROUP = _mockbrython
DD = _mockbrython
DEL = _mockbrython
DFN = _mockbrython
DIR = _mockbrython
DIV = _mockbrython
DL = _mockbrython
DT = _mockbrython
EM = _mockbrython
FIELDSET = _mockbrython
FONT = _mockbrython
FORM = _mockbrython
FRAME = _mockbrython
FRAMESET = _mockbrython
H1 = _mockbrython
H2 = _mockbrython
H3 = _mockbrython
H4 = _mockbrython
H5 = _mockbrython
H6 = _mockbrython
HEAD = _mockbrython
HR = _mockbrython
HTML = _mockbrython
I = _mockbrython
IFRAME = _mockbrython
IMG = _mockbrython
INPUT = _mockbrython
INS = _mockbrython
ISINDEX = _mockbrython
KBD = _mockbrython
LABEL = _mockbrython
LEGEND = _mockbrython
LI = _mockbrython
LINK = _mockbrython
MAP = _mockbrython
MENU = _mockbrython
META = _mockbrython
NOFRAMES = _mockbrython
NOSCRIPT = _mockbrython
OBJECT = _mockbrython
OL = _mockbrython
OPTGROUP = _mockbrython
OPTION = _mockbrython
P = _mockbrython
PARAM = _mockbrython
PRE = _mockbrython
Q = _mockbrython
S = _mockbrython
SAMP = _mockbrython
SCRIPT = _mockbrython
SELECT = _mockbrython
SMALL = _mockbrython
SPAN = _mockbrython
STRIKE = _mockbrython
STRONG = _mockbrython
STYLE = _mockbrython
SUB = _mockbrython
SUP = _mockbrython
SVG = _mockbrython
TABLE = _mockbrython
TBODY = _mockbrython
TD = _mockbrython
TEXTAREA = _mockbrython
TFOOT = _mockbrython
TH = _mockbrython
THEAD = _mockbrython
TITLE = _mockbrython
TR = _mockbrython
TT = _mockbrython
U = _mockbrython
UL = _mockbrython
VAR = _mockbrython

""" HTML5 tags """
ARTICLE = _mockbrython
ASIDE = _mockbrython
AUDIO = _mockbrython
BDI = _mockbrython
CANVAS = _mockbrython
COMMAND = _mockbrython
DATA = _mockbrython
DATALIST = _mockbrython
EMBED = _mockbrython
FIGCAPTION = _mockbrython
FIGURE = _mockbrython
FOOTER = _mockbrython
HEADER = _mockbrython
KEYGEN = _mockbrython
MAIN = _mockbrython
MARK = _mockbrython
MATH = _mockbrython
METER = _mockbrython
NAV = _mockbrython
OUTPUT = _mockbrython
PROGRESS = _mockbrython
RB = _mockbrython
RP = _mockbrython
RT = _mockbrython
RTC = _mockbrython
RUBY = _mockbrython
SECTION = _mockbrython
SOURCE = _mockbrython
SUMMARY = _mockbrython
TEMPLATE = _mockbrython
TIME = _mockbrython
TRACK = _mockbrython
VIDEO = _mockbrython
WBR = _mockbrython

""" HTML5.1 tags """

DETAILS = _mockbrython
DIALOG = _mockbrython
MENUITEM = _mockbrython
PICTURE = _mockbrython
SUMMARY = _mockbrython


def maketag(name):
    return _mockbrython


def attribute_mapper(attr):
    return _mockbrython


class _EV(_mockbrython):
    """ This class can create dummy events """

    def __init__(self, id):
        self.currentTarget = _mockbrython(id=id)



"""Mock brython timer functions """

def set_timeout(function,ms):
    pass
    
def clear_timeout(timer):
    pass

def set_interval(function,ms):
    function()

def clear_interval(timer):
    pass
def request_animation_frame(function):
    pass

def cancel_animation_frame(id):
    pass



class Menu():

    def __init__(self, container=None, default_css=True):
        pass

    def add_item(self, label, callback=None):
        pass

    def add_link(self, label, href):
        pass

    def add_menu(self, label):
        return Menu()
